==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Form</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formular</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="obsolete">Rasterabstand &lt; Meta Rasterabstand</translation>
    </message>
    <message>
        <source>Single</source>
        <translation type="obsolete">Einzel</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translation type="obsolete">Zwei: Vertikal</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translation type="obsolete">Zwei: Horizontal</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translation>Drei: Rechts</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translation>Drei: Links</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translation>Drei: Oben</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translation type="obsolete">Drei: Unten</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translation type="obsolete">Drei: Vertikal</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translation type="obsolete">Drei: Horizontal</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translation type="obsolete">Vier: Gleichmässig</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translation type="obsolete">Vier: Rechts</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translation type="obsolete">Vier: Links</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Vier: Gleichmässig</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Vier: Links</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Vier: Rechts</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Einzel</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Drei: Unten</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Drei: Horizontal</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Drei: Vertikal</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Zwei: Horizontal</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Zwei: Vertikal</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+320"/>
        <source>Grid</source>
        <translation>Raster</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Auf Objekt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Lotrecht</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Mittellinien</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Mittelpunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Schnittpunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referenz</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Rasterabstand &lt; Meta Rasterabstand</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Rasterabstand &lt; Meta Rasterabstand</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Form</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formular</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="obsolete">Rasterabstand &lt; Meta Rasterabstand</translation>
    </message>
    <message>
        <source>Single</source>
        <translation type="obsolete">Einzel</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translation type="obsolete">Zwei: Vertikal</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translation type="obsolete">Zwei: Horizontal</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translation>Drei: Rechts</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translation>Drei: Links</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translation>Drei: Oben</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translation type="obsolete">Drei: Unten</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translation type="obsolete">Drei: Vertikal</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translation type="obsolete">Drei: Horizontal</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translation type="obsolete">Vier: Gleichmässig</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translation type="obsolete">Vier: Rechts</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translation type="obsolete">Vier: Links</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Vier: Gleichmässig</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Vier: Links</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Vier: Rechts</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Einzel</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Drei: Unten</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Drei: Horizontal</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Drei: Vertikal</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Zwei: Horizontal</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Zwei: Vertikal</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+252"/>
        <source>Dropped data not supported</source>
        <translation>Eingefügte Daten nicht unterstützt</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Importing file: </source>
        <translation>Importiere Datei: </translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Importing URL: </source>
        <translation>Importiere URL: </translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="vanished">Raster</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="vanished">Ende</translation>
    </message>
    <message>
        <source>On Entity</source>
        <translation type="vanished">Auf Objekt</translation>
    </message>
    <message>
        <source>Perpendicular</source>
        <translation type="vanished">Lotrecht</translation>
    </message>
    <message>
        <source>Tangential</source>
        <translation type="vanished">Tangential</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Zentrum</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">Mitte</translation>
    </message>
    <message>
        <source>Intersection</source>
        <translation type="vanished">Schnittpunkt</translation>
    </message>
    <message>
        <source>Reference</source>
        <translation type="vanished">Referenz</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Rasterabstand &lt; Meta Rasterabstand</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Rasterabstand &lt; Meta Rasterabstand</translation>
    </message>
</context>
</TS>
